@@ -344,7 +344,7 @@ class ArtellaDriveClient(object):
         """
         Returns the project name giving its remote Artella ID
 
-        :param str project_id: ID of the project in remote Artelal server
+        :param str project_id: ID of the project in remote Artella server
         :param str remote_session: Remote session we want to search project on. If not given, the project will be
             search in all available remote sessions
         :return: Name of the project
@@ -392,12 +392,13 @@ class ArtellaDriveClient(object):
         Returns whether or not given file path is an Artella file path or not
         A path is considered to be an Artella path if the path is located inside the Artella project folder
         in the user machine
+
         :param str file_path: path to check. If not given, current DCC scene file path will be used
         :return: True if the given file path is an Artella path; False otherwise.
         :rtype: bool
         """
 
-        if not file_path or not os.path.isfile(file_path):
+        if not file_path or not os.path.exists(file_path):
             return False
 
         local_root = os.path.normpath(os.path.abspath(self.get_local_root()))
@@ -540,6 +541,25 @@ class ArtellaDriveClient(object):
 
         return translated_path
 
+    def is_path_translated(self, file_path):
+        """
+        Returns whether or not given path is already translated to a valid Artella path
+
+        :param file_path: str, path you want to check translation validation
+        :return: True if the given path is an already translated Artella path; False otherwise
+        :rtype: bool
+        :example:
+        >>> self.is_path_translated("C:/Users/Bobby/artella-files/ProjectA/Assets/Characters/A/Model/a.ma")
+        False
+        >>> self.is_path_translated("$ART_LOCAL_ROOT/ProjectA/refs/ref.png")
+        True
+        """
+
+        if not file_path:
+            return False
+
+        return file_path.startswith('${}'.format(consts.ALR))
+
     def convert_path(self, file_path):
         """
         Converts given path to a path that Artella can understand
@@ -696,7 +716,7 @@ class ArtellaDriveClient(object):
         if not self.get_remote_sessions(update=True):
             logger.warning(
                 'No remote sessions available. Artella App Drive status call aborted.')
-            return dict()
+            return list()
 
         file_paths = utils.force_list(file_paths, remove_duplicates=True)
         result = list()
@@ -917,7 +937,7 @@ class ArtellaDriveClient(object):
             rsp = self._communicate(req, json.dumps(payload).encode(), method='DELETE')
             if 'error' in rsp:
                 logger.error('Unable to unlock file path "{}" "{}"'.format(file_path, rsp.get('error')))
-                return False
+                return result
 
             if isinstance(rsp, dict):
                 result[file_path] = rsp.get('response', False) and rsp.get('status_code', 0) == 200
@@ -926,7 +946,7 @@ class ArtellaDriveClient(object):
                 # information. We consider that as a valid lock.
                 result[file_path] = True
 
-        return file_paths
+        return result
 
     def file_current_version(self, file_path, _status=None):
         """
@@ -992,7 +1012,7 @@ class ArtellaDriveClient(object):
 
     def can_lock_file(self, file_path):
         """
-        Returns whether or not current opened DCC file can locked or not
+        Returns whether or not current opened DCC file (or given file path) can be locked or not
         A file only can be locked if it is not already locked by other user.
 
         :param str or None file_path: Absolute local file path we want to check if can be locked or not.
@@ -1021,7 +1041,7 @@ class ArtellaDriveClient(object):
             - is_locked_by_me: True if the given file is locked by current user; False otherwise
             - locked_by_name: Name of the user that currently has the file locked
             - remote_record_found: Indicates whether the request relates to an existing remote file record or not
-        :rtype: tuple(bool, bool, str)
+        :rtype: tuple(bool, bool, str, bool)
         """
 
         payload = {
@@ -1042,6 +1062,17 @@ class ArtellaDriveClient(object):
         return is_locked, is_locked_by_me, locked_by_name, remote_record_found
 
     def get_progress(self):
+        """
+        Returns the download progress information of the current download operation from Artella server
+
+        :return: A tuple containing the following information:
+            - amount of done download operations
+            - amount of total download operations in progress
+            - amount of total download operations that are going to be done
+            - amount of total bytes downloaded
+            - amount of total bytes to download
+        :rtype: int, int, int, int, int
+        """
 
         tx_count_done = 0
         tx_count_total = 0
